## Summary

A narrative review aims to identify what has been written on a particular subject or topic without necessarily striving for generalizations. Unlike systematic reviews, narrative reviews can be selective and may not involve a comprehensive search of all relevant literature, instead relying on readily available sources. They typically lack detailed explanations of their review process, making them vulnerable to subjectivity and challenging to replicate. Data analysis in narrative reviews involves informal techniques to synthesize study findings, often accompanied by commentary or interpretation.

## Characteristics

| Dimension                  | Description                                                                                   |
|----------------------------|-----------------------------------------------------------------------------------------------|
| Goal with regard to theory | Describing                                                                                    |
| Scope of questions         | Broad                                                                                         |
| Methods                    | Not necessarily reported                                                                      |

## Data extraction, analysis, and synthesis

- The synthesis takes a narrative form to help readers make sense of the existing literature. This may involve different narrative styles, organized historically, conceptually, or author-centrically, along with instructive illustrations.

The following packages are automatically set up in a scoping review:

- [colrev.paper_md](colrev.paper_md.html)

## Examples

Chan, Y. E., & Reich, B. H. (2007). IT alignment: what have we learned?. *Journal of Information Technology*, 22(4), 297-315. doi:[10.1057/palgrave.jit.2000109](https://doi.org/10.1057/palgrave.jit.2000109)

## Methods papers

Davies, P. (2000). The relevance of systematic reviews to educational policy and practice. *Oxford Review of Education*, 26(3-4), 365-378. doi:[10.1080/713688543](https://doi.org/10.1080/713688543)

Green, B. N., Johnson, C. D., & Adams, A. (2006). Writing narrative literature reviews for peer-reviewed journals: secrets of the trade. *Journal of Chiropractic Medicine*, 5(3), 101-117. doi:[10.1016/S0899-3467(07)60142-6](https://doi.org/10.1016/S0899-3467(07)60142-6)
